Function bit_shift_visualization

pub fn bit_shift_visualization(value: &str)
Illustrates the concept of bit shifting; Takes a string a prints the bit and integer value of each character before performing a bit shift operation and printing the result as bit and integer values