Struct AdjacencyList

pub struct AdjacencyList<T, M> { /* private fields */ }
Represents a pointer bag design for an adjacency list graph representation. Nodes are identified by stable Vec indices for the lifetime of the graph.

Implementations

Source

impl<T, M> AdjacencyList<T, M>
where T: PartialEq,

pub fn new() -> Self

Creates a new, empty graph

pub fn add_node(&mut self, data: T) -> usize

Creates and adds a new vertex for the specified data

Creates and adds a new edge from an originating vertex to a destination vertex with an optional metadata element M such as a weight. Origin and destination arguments are positional for directed graphs.

Creates and adds a new undirected edge from one node to another node with an optional metadata element M such as a weight.

pub fn get_node(&self, index: usize) -> Option<&Node<T, M>>

Returns a reference to a node for a given index.

pub fn num_nodes(&self) -> usize

Returns the number of nodes in the graph

Returns the number of unique links in the graph

pub fn nodes(&self) -> &Vec<Node<T, M>>

Returns an iterable collection over all vertices in the graph

pub fn nodes_iter(&self) -> impl Iterator<Item = &Node<T, M>>

Returns an iterator over all vertices in the graph

Returns an iterator over all outgoing links for a given node

Returns an iterator over incoming links from a given node

Returns an iterator over all incoming links to a given node

Returns an iteratable collection over all links in the graph as { (u, (u → v)) | u ∈ V, (u → v) ∈ Adj[u] }

Returns an iterator over all links in the graph