pub fn navigator(level: usize, path: &Path)Expand description
A recursive function that chains the module’s utility functions to pretty-print a table of contents for each Markdown file in the specified directory; The is_file() path contains logic to build a tree from filtered values, skipping headers above the user-supplied level argument; The function also substitues the file name (if any) for all MD files not formatted with Astro’s frontmatter