Struct CursorMut

pub struct CursorMut<'a, T> { /* private fields */ }
CursorMut takes ’a to tie it to the tree’s lifetime which prevents dangling pointers by gating scopes

See module-level documentation for more details.

Implementations

Source

impl<'a, T> CursorMut<'a, T>

pub fn get_data(&self) -> Option<&T>

pub fn is_none(&self) -> bool

pub fn is_some(&self) -> bool

pub fn num_children(&self) -> usize

pub fn children_iter(&self) -> ChildIter<'a, T>

pub fn ascend(&mut self) -> Result<(), &str>

Uses Cell for interior mutability in order to retain signature semantics such that navigation methods retain &self borrows.

pub fn descend<F>(&mut self, predicate: F) -> Result<(), &str>
where F: Fn(&T) -> bool, T: 'a,

Uses a closure to descend to the correct child node. Ex:

pub fn add_child(&mut self, data: T)

Creates and adds a child Node to the position of the cursor, then moves the cursor to the new child Node.

pub fn delete(&mut self) -> Option<T>