pub struct GenTree<T> { /* private fields */ }Expand description
Represents the actual data structure. Currently this struct only has constructor methods to create a new tree and create new cursor handles which provide the lion’s share of tree operations.
See module-level documentation for more details.
Implementations