Struct ConcurrentSkipList

pub struct ConcurrentSkipList<T> { /* private fields */ }

Implementations

Source

impl<T: Ord> ConcurrentSkipList<T>

pub fn new() -> Self

Instantiates a new concurrent skip list.

pub fn len(&self) -> usize

Returns the number of nodes in the (base) list.

pub fn is_empty(&self) -> bool

Returns true if the (base) is empty.

pub fn push(&self, data: T) -> bool

Adds a new node to the list.

pub fn get<Q>(&self, key: &Q) -> Option<Arc<T>>
where Q: Ord + ?Sized, T: Borrow<Q>,

Returns a reference-counted pointer to the data in the node, if it exists.

pub fn remove<Q>(&self, key: &Q) -> Option<Arc<T>>
where Q: Ord + ?Sized, T: Borrow<Q>,

Removes a node from the list.

pub fn contains<Q>(&self, key: &Q) -> bool
where Q: Ord + ?Sized, T: Borrow<Q>,

Returns true if the item exists in the list.