Struct DynArray

pub struct DynArray<T> { /* private fields */ }
A dynamically sized, contiguous storage buffer with positive (forward) indexing, where elements are stored sequentially in memory.

Implementations

Source

impl<T> DynArray<T>

pub fn new() -> Self

pub fn new_with_capacity(cap: usize) -> Self

Pre-allocate for quicker operations

pub fn size(&mut self, val: T)

Warning: Unimplemented Returns the current number of elements in the list.

pub fn cap(&mut self, val: T)

Warning: Unimplemented Returns the current capacity of the list.

pub fn is_empty(&mut self, val: T) -> bool

Warning: Unimplemented Returns a Boolean indicating whether the list is empty.

pub fn push(&mut self, val: T)

Appends the list with an given element in O(1) time. If the list is at capacity, this operation automatically grows the list in O(n) time.

pub fn pop(&mut self)

Warning: Unimplemented Removes the last inserted element from the list.

pub fn remove(&mut self, index: usize)

Warning: Unimplemented Removes an element at the ith index in the list.

pub fn insert(&mut self, val: T, index: usize)

Warning: Unimplemented Inserts an element at a given index, forcing any remaining elements between i - list.len() to shift right. If the list is at capacity, the list automatically grows in O(n) time.

pub fn get(&mut self, index: usize) -> Option<T>

Warning: Unimplemented Returns