Enum Grade

pub enum Grade {
Show 14 variants INC, F, DMinus, D, DPlus, CMinus, C, CPlus, BMinus, B, BPlus, AMinus, A, APlus,
}
An equivalence class to categorize grades based on ranges of percentage point values. Derives PartialEq to reduce boilerplate. In Rust, the ordering of the discrimiants is important, such that the first listed discrimiant carries a value of 0, the next discrimiant a 1, and so on.

Variants



INC



F



DMinus



D



DPlus



CMinus



C



CPlus



BMinus



B



BPlus



AMinus



A



APlus

Implementations

Source

impl Grade

pub fn eq_class(value: f32) -> Grade

Maps a score into its corresponding equivalence class