pub struct CursorMut<'a, T> { /* private fields */ }Expand description
CursorMut takes ’a to tie it to the tree’s lifetime which prevents dangling pointers by gating scopes
See module-level documentation for more details.
Implementations
Sourceimpl<'a, T> CursorMut<'a, T>
impl<'a, T> CursorMut<'a, T>
pub fn get_data(&self) -> Option<&T>
pub fn is_none(&self) -> bool
pub fn is_some(&self) -> bool
pub fn num_children(&self) -> usize
pub fn children_iter(&self) -> ChildIter<'a, T> ⓘ
Sourcepub fn ascend(&mut self) -> Result<(), &str>
pub fn ascend(&mut self) -> Result<(), &str>
Uses Cell for interior mutability in order to retain signature semantics such that navigation methods retain &self borrows.
Sourcepub fn descend<F>(&mut self, predicate: F) -> Result<(), &str>
pub fn descend<F>(&mut self, predicate: F) -> Result<(), &str>
Uses a closure to descend to the correct child node. Ex:
Sourcepub fn add_child(&mut self, data: T)
pub fn add_child(&mut self, data: T)
Creates and adds a child Node to the position of the cursor,
then moves the cursor to the new child Node.
pub fn delete(&mut self) -> Option<T>