Struct SkipList

pub struct SkipList<T> { /* private fields */ }

Implementations

Source

impl<T: Ord> SkipList<T>

pub fn new() -> Self

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn locate<Q>(&self, key: &Q) -> Option<usize>
where Q: Ord + ?Sized, T: Borrow<Q>,

pub fn contains<Q>(&self, key: &Q) -> bool
where Q: Ord + ?Sized, T: Borrow<Q>,

pub fn insert(&mut self, value: T)
where T: Ord,

pub fn remove<Q>(&mut self, key: &Q) -> Option<T>
where Q: Ord + ?Sized, T: Borrow<Q>,

Removes and returns the value for a given key, if it exists in the list.

pub fn get_kth(&self, k: usize) -> Option<&T>

Returns the Kth value in the list, if it exists.

pub fn range<Q, R>(&self, range: R) -> RangeIter<'_, T, Q, R>
where Q: Ord + ?Sized, T: Borrow<Q>, R: RangeBounds<Q>,

Returns an inclusive iterator over a range of values in the list from start to end.

pub fn iter(&self) -> Iter<'_, T>